@@ -2,7 +2,7 @@
  *
  * lttng-kernel-version.h
  *
- * Contains helpers to check more complex kernel version conditions.
+ * Contains helpers to check kernel version conditions.
  *
  * Copyright (C) 2012 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
  */
@@ -12,28 +12,74 @@
 
 #include <linux/version.h>
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33))
+/*
+ * The following defines are extracted from the toplevel Linux Makefile and
+ * passed on the command line -with '-D'.
+ */
+
+#ifndef LTTNG_LINUX_MAJOR
+#define LTTNG_LINUX_MAJOR 0
+#endif
+
+#ifndef LTTNG_LINUX_MINOR
+#define LTTNG_LINUX_MINOR 0
+#endif
+
+#ifndef LTTNG_LINUX_PATCH
+#define LTTNG_LINUX_PATCH 0
+#endif
+
+/*
+ * Some stable releases have overflowed the 8bits allocated to the sublevel in
+ * the version code. To determine if the current kernel is affected, use the
+ * sublevel version from the Makefile. This is currently true for the 4.4.256
+ * and 4.9.256 stable releases.
+ *
+ * When the sublevel has overflowed, use the values from the Makefile instead
+ * of LINUX_VERSION_CODE from the kernel headers and allocate 16bits.
+ * Otherwise, keep using the version code from the headers to minimise the
+ * behavior change and avoid regressions.
+ *
+ * Cast the result to uint64_t to prevent overflowing when we append distro
+ * specific version information.
+ */
+#if (LTTNG_LINUX_PATCH >= 256)
+
+#define LTTNG_KERNEL_VERSION(a, b, c) \
+	((((a) << 24) + ((b) << 16) + (c)) * 1ULL)
+
+#define LTTNG_LINUX_VERSION_CODE \
+	LTTNG_KERNEL_VERSION(LTTNG_LINUX_MAJOR, LTTNG_LINUX_MINOR, LTTNG_LINUX_PATCH)
+
+#else
+
+#define LTTNG_KERNEL_VERSION(a, b, c) (KERNEL_VERSION(a, b, c) * 1ULL)
+#define LTTNG_LINUX_VERSION_CODE (LINUX_VERSION_CODE * 1ULL)
+
+#endif
+
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,33))
 #include <generated/utsrelease.h>
-#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)) */
+#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,33)) */
 #include <linux/utsrelease.h>
-#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)) */
+#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,33)) */
 
 /*
  * This macro checks if the kernel version is between the two specified
  * versions (lower limit inclusive, upper limit exclusive).
  */
 #define LTTNG_KERNEL_RANGE(a_low, b_low, c_low, a_high, b_high, c_high) \
-	(LINUX_VERSION_CODE >= KERNEL_VERSION(a_low, b_low, c_low) && \
-	 LINUX_VERSION_CODE < KERNEL_VERSION(a_high, b_high, c_high))
+	(LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(a_low, b_low, c_low) && \
+	 LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(a_high, b_high, c_high))
 
 /* Ubuntu */
 
 #define LTTNG_UBUNTU_KERNEL_VERSION(a, b, c, d) \
-	(((a) << 24) + ((b) << 16) + ((c) << 8) + (d))
+	(((LTTNG_KERNEL_VERSION(a, b, c)) << 16) + (d))
 
 #ifdef UTS_UBUNTU_RELEASE_ABI
 #define LTTNG_UBUNTU_VERSION_CODE \
-	((LINUX_VERSION_CODE << 8) + UTS_UBUNTU_RELEASE_ABI)
+	((LTTNG_LINUX_VERSION_CODE << 16) + UTS_UBUNTU_RELEASE_ABI)
 #else
 #define LTTNG_UBUNTU_VERSION_CODE 	0
 #endif
@@ -48,11 +94,11 @@
 /* Debian */
 
 #define LTTNG_DEBIAN_KERNEL_VERSION(a, b, c, d, e, f) \
-	(((((a) << 16) + ((b) << 8) + (c)) * 1000000ULL) + ((d) * 10000) + ((e) * 100) + (f))
+	(((LTTNG_KERNEL_VERSION(a, b, c)) * 1000000ULL) + ((d) * 10000) + ((e) * 100) + (f))
 
 #ifdef DEBIAN_API_VERSION
 #define LTTNG_DEBIAN_VERSION_CODE \
-	((LINUX_VERSION_CODE * 1000000ULL) + DEBIAN_API_VERSION)
+	((LTTNG_LINUX_VERSION_CODE * 1000000ULL) + DEBIAN_API_VERSION)
 #else
 #define LTTNG_DEBIAN_VERSION_CODE	0
 #endif
@@ -65,13 +111,13 @@
 		LTTNG_DEBIAN_KERNEL_VERSION(a_high, b_high, c_high, d_high, e_high, f_high))
 
 #define LTTNG_RHEL_KERNEL_VERSION(a, b, c, d, e, f) \
-	(((((a) << 16) + ((b) << 8) + (c)) * 10000000ULL) + ((d) * 10000) + ((e) * 100) + (f))
+	(((LTTNG_KERNEL_VERSION(a, b, c)) * 100000000ULL) + ((d) * 10000) + ((e) * 100) + (f))
 
 /* RHEL */
 
 #ifdef RHEL_API_VERSION
 #define LTTNG_RHEL_VERSION_CODE \
-	((LINUX_VERSION_CODE * 10000000ULL) + RHEL_API_VERSION)
+	((LTTNG_LINUX_VERSION_CODE * 100000000ULL) + RHEL_API_VERSION)
 #else
 #define LTTNG_RHEL_VERSION_CODE		0
 #endif
@@ -86,11 +132,11 @@
 /* SUSE Linux enterprise */
 
 #define LTTNG_SLE_KERNEL_VERSION(a, b, c, d, e, f) \
-	(((((a) << 16) + ((b) << 8) + (c)) * 10000000ULL) + ((d) * 10000) + ((e) * 100) + (f))
+	(((LTTNG_KERNEL_VERSION(a, b, c)) * 100000000ULL) + ((d) * 100000) + ((e) * 100) + (f))
 
 #ifdef SLE_API_VERSION
 #define LTTNG_SLE_VERSION_CODE \
-	((LINUX_VERSION_CODE * 10000000ULL) + SLE_API_VERSION)
+	((LTTNG_LINUX_VERSION_CODE * 100000000ULL) + SLE_API_VERSION)
 #else
 #define LTTNG_SLE_VERSION_CODE 	0
 #endif
@@ -105,11 +151,11 @@
 /* Fedora */
 
 #define LTTNG_FEDORA_KERNEL_VERSION(a, b, c, d) \
-        (((((a) << 16) + ((b) << 8) + (c)) * 10000ULL) + (d))
+        (((LTTNG_KERNEL_VERSION(a, b, c)) * 10000ULL) + (d))
 
 #ifdef FEDORA_REVISION_VERSION
 #define LTTNG_FEDORA_VERSION_CODE \
-        ((LINUX_VERSION_CODE * 10000ULL) + FEDORA_REVISION_VERSION)
+        ((LTTNG_LINUX_VERSION_CODE * 10000ULL) + FEDORA_REVISION_VERSION)
 #else
 #define LTTNG_FEDORA_VERSION_CODE         0
 #endif
@@ -124,11 +170,11 @@
 /* RT patch */
 
 #define LTTNG_RT_KERNEL_VERSION(a, b, c, d) \
-	(((a) << 24) + ((b) << 16) + ((c) << 8) + (d))
+	(((LTTNG_KERNEL_VERSION(a, b, c)) << 16) + (d))
 
 #ifdef RT_PATCH_VERSION
 #define LTTNG_RT_VERSION_CODE \
-	((LINUX_VERSION_CODE << 8) + RT_PATCH_VERSION)
+	((LTTNG_LINUX_VERSION_CODE << 16) + RT_PATCH_VERSION)
 #else
 #define LTTNG_RT_VERSION_CODE 	0
 #endif
