@@ -55,13 +55,42 @@
 #define LTTNG_INSTRUMENTATION
 #include <instrumentation/events/lttng-module/lttng-statedump.h>
 
-DEFINE_TRACE(lttng_statedump_block_device);
-DEFINE_TRACE(lttng_statedump_end);
-DEFINE_TRACE(lttng_statedump_interrupt);
-DEFINE_TRACE(lttng_statedump_file_descriptor);
-DEFINE_TRACE(lttng_statedump_start);
-DEFINE_TRACE(lttng_statedump_process_state);
-DEFINE_TRACE(lttng_statedump_network_interface);
+LTTNG_DEFINE_TRACE(lttng_statedump_block_device,
+	TP_PROTO(struct lttng_session *session,
+		dev_t dev, const char *diskname),
+	TP_ARGS(session, dev, diskname));
+
+LTTNG_DEFINE_TRACE(lttng_statedump_end,
+	TP_PROTO(struct lttng_session *session),
+	TP_ARGS(session));
+
+LTTNG_DEFINE_TRACE(lttng_statedump_interrupt,
+	TP_PROTO(struct lttng_session *session,
+		unsigned int irq, const char *chip_name,
+		struct irqaction *action),
+	TP_ARGS(session, irq, chip_name, action));
+
+LTTNG_DEFINE_TRACE(lttng_statedump_file_descriptor,
+	TP_PROTO(struct lttng_session *session,
+		struct task_struct *p, int fd, const char *filename,
+		unsigned int flags, fmode_t fmode),
+	TP_ARGS(session, p, fd, filename, flags, fmode));
+
+LTTNG_DEFINE_TRACE(lttng_statedump_start,
+	TP_PROTO(struct lttng_session *session),
+	TP_ARGS(session));
+
+LTTNG_DEFINE_TRACE(lttng_statedump_process_state,
+	TP_PROTO(struct lttng_session *session,
+		struct task_struct *p,
+		int type, int mode, int submode, int status,
+		struct pid_namespace *pid_ns),
+	TP_ARGS(session, p, type, mode, submode, status, pid_ns));
+
+LTTNG_DEFINE_TRACE(lttng_statedump_network_interface,
+	TP_PROTO(struct lttng_session *session,
+		struct net_device *dev, struct in_ifaddr *ifa),
+	TP_ARGS(session, dev, ifa));
 
 struct lttng_fd_ctx {
 	char *page;
@@ -107,6 +136,116 @@ enum lttng_process_status {
 	LTTNG_DEAD = 7,
 };
 
+
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,11,0))
+
+#define LTTNG_PART_STRUCT_TYPE struct block_device
+
+static
+int lttng_get_part_name(struct gendisk *disk, struct block_device *part, char *name_buf)
+{
+	const char *p;
+
+	p = bdevname(part, name_buf);
+	if (!p)
+		return -ENOSYS;
+
+	return 0;
+}
+
+static
+dev_t lttng_get_part_devt(struct block_device *part)
+{
+	return part->bd_dev;
+}
+
+#else
+
+#define LTTNG_PART_STRUCT_TYPE struct hd_struct
+
+static
+int lttng_get_part_name(struct gendisk *disk, struct hd_struct *part, char *name_buf)
+{
+	const char *p;
+	struct block_device bdev;
+
+	/*
+	 * Create a partial 'struct blockdevice' to use
+	 * 'bdevname()' which is a simple wrapper over
+	 * 'disk_name()' but has the honor to be EXPORT_SYMBOL.
+	 */
+	bdev.bd_disk = disk;
+	bdev.bd_part = part;
+
+	p = bdevname(&bdev, name_buf);
+	if (!p)
+		return -ENOSYS;
+
+	return 0;
+}
+
+static
+dev_t lttng_get_part_devt(struct hd_struct *part)
+{
+	return part_devt(part);
+}
+#endif
+
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,12,0))
+static
+int lttng_statedump_each_block_device(struct lttng_session *session, struct gendisk *disk)
+{
+	struct block_device *part;
+	unsigned long idx;
+	int ret = 0;
+
+	/* Include partition 0 */
+	idx = 0;
+
+	rcu_read_lock();
+	xa_for_each(&disk->part_tbl, idx, part) {
+		char name_buf[BDEVNAME_SIZE];
+
+		/* Exclude non-partitions bdev and empty partitions. */
+		if (bdev_is_partition(part) && !bdev_nr_sectors(part))
+			continue;
+
+		if (lttng_get_part_name(disk, part, name_buf) == -ENOSYS) {
+			ret = -ENOSYS;
+			goto end;
+		}
+		trace_lttng_statedump_block_device(session, lttng_get_part_devt(part),
+				name_buf);
+	}
+end:
+	rcu_read_unlock();
+	return ret;
+}
+#else
+static
+int lttng_statedump_each_block_device(struct lttng_session *session, struct gendisk *disk)
+{
+	struct disk_part_iter piter;
+	LTTNG_PART_STRUCT_TYPE *part;
+
+	disk_part_iter_init(&piter, disk, DISK_PITER_INCL_PART0);
+
+	while ((part = disk_part_iter_next(&piter))) {
+		char name_buf[BDEVNAME_SIZE];
+
+		if (lttng_get_part_name(disk, part, name_buf) == -ENOSYS) {
+			disk_part_iter_exit(&piter);
+			return -ENOSYS;
+		}
+		trace_lttng_statedump_block_device(session, lttng_get_part_devt(part),
+				name_buf);
+	}
+	disk_part_iter_exit(&piter);
+
+	return 0;
+}
+#endif
+
 static
 int lttng_enumerate_block_devices(struct lttng_session *session)
 {
@@ -114,19 +253,21 @@ int lttng_enumerate_block_devices(struct lttng_session *session)
 	struct device_type *ptr_disk_type;
 	struct class_dev_iter iter;
 	struct device *dev;
+	int ret = 0;
 
 	ptr_block_class = wrapper_get_block_class();
-	if (!ptr_block_class)
-		return -ENOSYS;
+	if (!ptr_block_class) {
+		ret = -ENOSYS;
+		goto end;
+	}
 	ptr_disk_type = wrapper_get_disk_type();
 	if (!ptr_disk_type) {
-		return -ENOSYS;
+		ret = -ENOSYS;
+		goto end;
 	}
 	class_dev_iter_init(&iter, ptr_block_class, NULL, ptr_disk_type);
 	while ((dev = class_dev_iter_next(&iter))) {
-		struct disk_part_iter piter;
 		struct gendisk *disk = dev_to_disk(dev);
-		struct hd_struct *part;
 
 		/*
 		 * Don't show empty devices or things that have been
@@ -136,33 +277,11 @@ int lttng_enumerate_block_devices(struct lttng_session *session)
 		    (disk->flags & GENHD_FL_SUPPRESS_PARTITION_INFO))
 			continue;
 
-		disk_part_iter_init(&piter, disk, DISK_PITER_INCL_PART0);
-		while ((part = disk_part_iter_next(&piter))) {
-			struct block_device bdev;
-			char name_buf[BDEVNAME_SIZE];
-			const char *p;
-
-			/*
-			 * Create a partial 'struct blockdevice' to use
-			 * 'bdevname()' which is a simple wrapper over
-			 * 'disk_name()' but has the honor to be EXPORT_SYMBOL.
-			 */
-			bdev.bd_disk = disk;
-			bdev.bd_part = part;
-
-			p = bdevname(&bdev, name_buf);
-			if (!p) {
-				disk_part_iter_exit(&piter);
-				class_dev_iter_exit(&iter);
-				return -ENOSYS;
-			}
-			trace_lttng_statedump_block_device(session,
-					part_devt(part), name_buf);
-		}
-		disk_part_iter_exit(&piter);
+		ret = lttng_statedump_each_block_device(session, disk);
 	}
 	class_dev_iter_exit(&iter);
-	return 0;
+end:
+	return ret;
 }
 
 #ifdef CONFIG_INET
@@ -337,7 +456,7 @@ int lttng_enumerate_vm_maps(struct lttng_session *session)
 
 #ifdef CONFIG_LTTNG_HAS_LIST_IRQ
 
-#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,39))
+#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(2,6,39))
 #define irq_desc_get_chip(desc) get_irq_desc_chip(desc)
 #endif
 
